;; Generated package description from djvu.el  -*- no-byte-compile: t -*-
(define-package "djvu" "1.1.2.0.20221212.223055" "Edit and view Djvu files via djvused" 'nil :commit "e20134788c4556c4c0a15edf5870a4d44186bee1" :url "https://elpa.gnu.org/packages/djvu.html" :authors '(("Roland Winkler" . "winkler@gnu.org")) :maintainer '("Roland Winkler" . "winkler@gnu.org") :keywords '("files" "wp"))
